==> pyminer-2.1.1-py3-none-any.whl: pyminer/packages/code_editor/assets/languages/zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>FindInPathWidget</name>
    <message>
        <location filename="../../widgets/ui/findinpath.py" line="33"/>
        <source>Case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/ui/findinpath.py" line="35"/>
        <source>Whole Word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/ui/findinpath.py" line="36"/>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/ui/findinpath.py" line="48"/>
        <source>Find In Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/ui/findinpath.py" line="91"/>
        <source>line</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMBaseCodeEdit</name>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="159"/>
        <source>Format Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="163"/>
        <source>Run Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="167"/>
        <source>Run Selected Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="171"/>
        <source>Save Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="174"/>
        <source>Find Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="177"/>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="180"/>
        <source>Find In Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="183"/>
        <source>AutoComp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="186"/>
        <source>Goto Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="189"/>
        <source>Goto Definition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="192"/>
        <source>Function Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="195"/>
        <source>Help in Console</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="199"/>
        <source>Add Breakpoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="201"/>
        <source>Remove Breakpoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="203"/>
        <source>View BreakPoints</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMBaseEditor</name>
    <message>
        <location filename="../../widgets/editors/base_editor.py" line="214"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/editors/base_editor.py" line="214"/>
        <source>Save file &quot;{0}&quot;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/editors/base_editor.py" line="261"/>
        <source>Save file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMCodeEditTabWidget</name>
    <message>
        <location filename="../../widgets/tab_widget.py" line="686"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="305"/>
        <source>Editor does not support file:
%s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="394"/>
        <source>Open File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="522"/>
        <source>Run: %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="528"/>
        <source>Run Python Code inside %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="605"/>
        <source>Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="616"/>
        <source>Builtin (3.8.5)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="686"/>
        <source>This Editor does not support instant boot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="696"/>
        <source>Builtin (%s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="788"/>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="798"/>
        <source>Find In Path</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMDebugConsoleTabWidget</name>
    <message>
        <location filename="../../widgets/debugger.py" line="23"/>
        <source>Debugger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/debugger.py" line="80"/>
        <source>Terminate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/debugger.py" line="81"/>
        <source>Process is running, Would you like to terminate this process?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMEditorToolbar</name>
    <message>
        <location filename="../../widgets/toolbar.py" line="10"/>
        <source>New Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="14"/>
        <source>Open Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="17"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="21"/>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="24"/>
        <source>Toggle Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="24"/>
        <source>Goto Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="30"/>
        <source>Indent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="30"/>
        <source>Dedent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="34"/>
        <source>IPython</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="37"/>
        <source>Separately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="39"/>
        <source>Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="45"/>
        <source>Instant Boot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="46"/>
        <source>Run script with common module preloaded to shorten interpterter startup-time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="56"/>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMFindDialog</name>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="20"/>
        <source>Text to Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="21"/>
        <source>Text to Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="22"/>
        <source>Wrap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="23"/>
        <source>Regex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="24"/>
        <source>Case Sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="25"/>
        <source>Whole Word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="30"/>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="31"/>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="32"/>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="33"/>
        <source>Replace All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMGotoLineDialog</name>
    <message>
        <location filename="../../widgets/dialogs/goto_line_dialog.py" line="47"/>
        <source>Input Value Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/goto_line_dialog.py" line="43"/>
        <source>Cannot convert &apos;%s&apos; to integer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/goto_line_dialog.py" line="48"/>
        <source>Line Number {line} out of range!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context encoding="UTF-8">
    <name>PMPythonEditor</name>
    <message>
        <location filename="../../widgets/editors/python_editor.py" line="254"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../widgets/editors/python_editor.py" line="258"/>
        <source>Cannot get name.
Maybe There is:
1、Syntax error in your code.
2、No word under text cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/editors/python_editor.py" line="334"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> pyminer-2.1.2-py3-none-any.whl: pyminer/packages/code_editor/assets/languages/zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>BaseHandler</name>
    <message>
        <location filename="../../code_handlers/base_handler.py" line="80"/>
        <source>run code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../code_handlers/base_handler.py" line="84"/>
        <source>run selected code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CodeEditorBaseObject</name>
    <message>
        <location filename="../../utils/base_object.py" line="62"/>
        <source>Not Implemented Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../utils/base_object.py" line="62"/>
        <source>{} is not implemented</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FindInPathWidget</name>
    <message>
        <location filename="../../widgets/ui/findinpath.py" line="33"/>
        <source>Case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/ui/findinpath.py" line="35"/>
        <source>Whole Word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/ui/findinpath.py" line="36"/>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/ui/findinpath.py" line="48"/>
        <source>Find In Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/ui/findinpath.py" line="91"/>
        <source>line</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMBaseCodeEdit</name>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="176"/>
        <source>Format Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="180"/>
        <source>Run Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="185"/>
        <source>Run Selected Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="189"/>
        <source>Save Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="192"/>
        <source>Find Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="195"/>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="198"/>
        <source>Find In Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="201"/>
        <source>AutoComp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="204"/>
        <source>Goto Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="207"/>
        <source>Goto Definition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="210"/>
        <source>Function Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="213"/>
        <source>Help in Console</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="217"/>
        <source>Add Breakpoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="219"/>
        <source>Remove Breakpoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="221"/>
        <source>View BreakPoints</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="182"/>
        <source>Running {}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="225"/>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="225"/>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="225"/>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="225"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="226"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="226"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/text_edit/base_text_edit.py" line="228"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMBaseEditor</name>
    <message>
        <location filename="../../widgets/editors/base_editor.py" line="215"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/editors/base_editor.py" line="215"/>
        <source>Save file &quot;{0}&quot;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/editors/base_editor.py" line="262"/>
        <source>Save file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/editors/base_editor.py" line="386"/>
        <source>instant boot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMCodeEditTabWidget</name>
    <message>
        <location filename="../../widgets/tab_widget.py" line="258"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="259"/>
        <source>Editor does not support file:
%s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="343"/>
        <source>Open File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="393"/>
        <source>Run: %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="398"/>
        <source>Run Python Code inside %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="446"/>
        <source>Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="457"/>
        <source>Builtin (3.8.5)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="499"/>
        <source>Builtin (%s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="568"/>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/tab_widget.py" line="578"/>
        <source>Find In Path</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMDebugConsoleTabWidget</name>
    <message>
        <location filename="../../widgets/debugger.py" line="23"/>
        <source>Debugger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/debugger.py" line="80"/>
        <source>Terminate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/debugger.py" line="81"/>
        <source>Process is running, Would you like to terminate this process?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMEditorToolbar</name>
    <message>
        <location filename="../../widgets/toolbar.py" line="10"/>
        <source>New Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="14"/>
        <source>Open Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="17"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="21"/>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="24"/>
        <source>Toggle Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="24"/>
        <source>Goto Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="30"/>
        <source>Indent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="30"/>
        <source>Dedent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="34"/>
        <source>IPython</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="37"/>
        <source>Separately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="39"/>
        <source>Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="45"/>
        <source>Instant Boot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="46"/>
        <source>Run script with common module preloaded to shorten interpterter startup-time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/toolbar.py" line="56"/>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMFindDialog</name>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="20"/>
        <source>Text to Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="21"/>
        <source>Text to Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="22"/>
        <source>Wrap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="23"/>
        <source>Regex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="24"/>
        <source>Case Sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="25"/>
        <source>Whole Word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="30"/>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="31"/>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="32"/>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/find_dialog.py" line="33"/>
        <source>Replace All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMGotoLineDialog</name>
    <message>
        <location filename="../../widgets/dialogs/goto_line_dialog.py" line="47"/>
        <source>Input Value Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/goto_line_dialog.py" line="43"/>
        <source>Cannot convert &apos;%s&apos; to integer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../widgets/dialogs/goto_line_dialog.py" line="48"/>
        <source>Line Number {line} out of range!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context encoding="UTF-8">
    <name>PMPythonEditor</name>
    <message>
        <location filename="../../widgets/editors/python_editor.py" line="252"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../widgets/editors/python_editor.py" line="256"/>
        <source>Cannot get name.
Maybe There is:
1、Syntax error in your code.
2、No word under text cursor.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PythonHandler</name>
    <message>
        <location filename="../../code_handlers/python_handler.py" line="14"/>
        <source>Run code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
